summaryrefslogtreecommitdiff
path: root/src/game-server/monster.hpp
diff options
context:
space:
mode:
authorBjørn Lindeijer <bjorn@lindeijer.nl>2009-04-23 21:00:16 +0200
committerBjørn Lindeijer <bjorn@lindeijer.nl>2009-04-26 17:18:21 +0200
commite726c34606f85347e70a0deb6b180db03b6d0c25 (patch)
treee78e5ba07dd9484abed035cc3e63744101bbef57 /src/game-server/monster.hpp
parenta3f72002fa02cd4c525f101c5f240a22d4480119 (diff)
downloadmanaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.gz
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.bz2
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.tar.xz
manaserv-e726c34606f85347e70a0deb6b180db03b6d0c25.zip
Merged MovingObject into the Being class
Also renamed Object to Actor, to make it sound a little less generic. Cleans up a bit the rather big hierarchy of different object types we have.
Diffstat (limited to 'src/game-server/monster.hpp')
-rw-r--r--src/game-server/monster.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/game-server/monster.hpp b/src/game-server/monster.hpp
index ab60fe0e..b7c5947f 100644
--- a/src/game-server/monster.hpp
+++ b/src/game-server/monster.hpp
@@ -249,7 +249,7 @@ class Monster : public Being
/**
* Calls the damage function in Being and updates the aggro list
*/
- virtual int damage(Object *source, Damage const &damage);
+ virtual int damage(Actor *source, Damage const &damage);
/**
* Removes a being from the anger list.
@@ -257,7 +257,7 @@ class Monster : public Being
void forgetTarget(Thing *being);
/**
* Returns the way the object is blocked by other things on the map
*/
virtual unsigned char getWalkMask() const
{
@@ -267,7 +267,7 @@ class Monster : public Being
protected:
/**
* Returns the way the object blocks pathfinding for other objects
*/
virtual Map::BlockType getBlockType() const
{ return Map::BLOCKTYPE_MONSTER; }
@@ -257,7 +257,7 @@ class Monster : public Being
void forgetTarget(Thing *being);
/**
- * Returns the way the object is blocked by other things on the map
+ * Returns the way the actor is blocked by other things on the map.
*/
virtual unsigned char getWalkMask() const
@@ -267,7 +267,7 @@ class Monster : public Being
protected:
/**
- * Returns the way the object blocks pathfinding for other objects
+ * Returns the way the actor blocks pathfinding for other objects.
*/
virtual Map::BlockType getBlockType() const